==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebStringFilteringOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperandDescriptionMetadata } from "./WebFilteringOperandDescriptionMetadata";
import { WebStringFilteringOperandDescription } from "./WebStringFilteringOperandDescription";
/**
 * @hidden
 */
export let WebStringFilteringOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebStringFilteringOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebStringFilteringOperandDescriptionMetadata.a == null) {
                WebStringFilteringOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebStringFilteringOperandDescriptionMetadata.c(WebStringFilteringOperandDescriptionMetadata.a);
            }
            if (a.k(WebStringFilteringOperandDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebStringFilteringOperandDescriptionMetadata.a);
        }
        static c(a) {
            WebFilteringOperandDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:StringFilteringOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebStringFilteringOperandDescriptionMetadata.b(a);
            a.ad("WebStringFilteringOperand", () => new WebStringFilteringOperandDescription());
            a.ac("WebStringFilteringOperand", WebStringFilteringOperandDescriptionMetadata.a);
        }
    }
    WebStringFilteringOperandDescriptionMetadata.$t = markType(WebStringFilteringOperandDescriptionMetadata, 'WebStringFilteringOperandDescriptionMetadata');
    WebStringFilteringOperandDescriptionMetadata.a = null;
    return WebStringFilteringOperandDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebStringFilteringOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperandDescriptionMetadata } from "./WebFilteringOperandDescriptionMetadata";
import { WebStringFilteringOperandDescription } from "./WebStringFilteringOperandDescription";
/**
 * @hidden
 */
export let WebStringFilteringOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebStringFilteringOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebStringFilteringOperandDescriptionMetadata.a == null) {
                WebStringFilteringOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebStringFilteringOperandDescriptionMetadata.c(WebStringFilteringOperandDescriptionMetadata.a);
            }
            if (a.k(WebStringFilteringOperandDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebStringFilteringOperandDescriptionMetadata.a);
        }
        static c(a) {
            WebFilteringOperandDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:StringFilteringOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebStringFilteringOperandDescriptionMetadata.b(a);
            a.ae("WebStringFilteringOperand", () => new WebStringFilteringOperandDescription());
            a.ad("WebStringFilteringOperand", WebStringFilteringOperandDescriptionMetadata.a);
        }
    }
    WebStringFilteringOperandDescriptionMetadata.$t = markType(WebStringFilteringOperandDescriptionMetadata, 'WebStringFilteringOperandDescriptionMetadata');
    WebStringFilteringOperandDescriptionMetadata.a = null;
    return WebStringFilteringOperandDescriptionMetadata;
})();
